secretmanager

package
v0.0.0-...-9ff4336 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 6, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service interface {
	secretIfc.SecretsManagerAPI
}

func NewSM

func NewSM(ctx ctx.CTX, awsRegion string) (smSrv Service)

NewSM for new secrets manager api based on default aws credentials

func NewSMWithAssumeRole

func NewSMWithAssumeRole(ctx ctx.CTX, awsRegion, assumeRoleARN string) Service

NewSMWithAssumeRole for new secrets manager api with assume role

Directories

Path Synopsis

Jump to